package org.acme.rest.json;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class FruitResourceIT extends FruitResourceTest {

}